@@ -1,4 +1,4 @@
-"""Python compatiblity utilities."""
+"""Python compatibility utilities."""
 from __future__ import absolute_import, unicode_literals
 
 from functools import (
